@@ -7,8 +7,8 @@ name = "WZCMCCAPPLOGGER"
 #API  DB  Redis
 log_type="DB"
 dbhost ='10.77.18.248,8433';
-dbuser ='sa'
-dbpwd= 'zhyw$zj123'
+dbuser ='cmcclogger'
+dbpwd= 'log$zj123'
 dbname = 'WZGJGLAPI'
 
 def InsertLog():
@@ -19,7 +19,7 @@ def InsertLog():
     ip = WZCMCCAPPLOGGER.GetNetWorkInfo.get_hostip();
 
     sql ="""insert into CMCCAPPLOG(APPID,MAC,IP)  values ('{pcname}','{mac}','{ip}')""".format(pcname=pcname,mac=mac,ip=ip)
-    _Obdcsql = LogUploader.Obdcsql('10.77.18.248,8433','sa','zhyw$zj123','WZGJGLAPI')
+    _Obdcsql = LogUploader.Obdcsql(dbhost,dbuser,dbpwd,dbname)
     _Obdcsql.insert_record(sql)
 
 #InsertLog()
